# -*- coding: utf-8 -*-
# (c) 2015 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com
from django.utils.unittest import TestCase
from english_filters.templatetags.english_filters import join_or, join_and


class JoinTests(TestCase):
    def test_join_or_empty_list(self):
        self.assertEqual(u'',
                         join_or([]))

    def test_join_or_one_number(self):
        self.assertEqual(u'123',
                         join_or([123]))

    def test_join_or_2_numbers(self):
        self.assertEqual(u'123 or 456',
                         join_or([123, 456]))

    def test_join_or_3_numbers(self):
        self.assertEqual(u'123, 456 or 7',
                         join_or([123, 456, 7]))

    def test_join_or_4_numbers(self):
        self.assertEqual(u'123, 456, 42 or 321',
                         join_or([123, 456, 42, 321]))

    def test_join_or_3_strings(self):
        self.assertEqual(u'Peter, Jane or Mary',
                         join_or(['Peter', 'Jane', 'Mary']))

    def test_join_or_escapes_when_autoescape_true(self):
        self.assertEqual('&lt; or &gt;',
                         join_or(['<', '>'], autoescape=True))

    def test_join_and_escapes_when_autoescape_true(self):
        self.assertEqual('&lt; and &gt;',
                         join_and(['<', '>'], autoescape=True))

    def test_join_and_3_strings(self):
        self.assertEqual(u'Peter, Jane and Mary',
                         join_and(['Peter', 'Jane', 'Mary']))



# -*- coding: utf-8 -*-
# (c) 2015 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com
from django import template
from django.utils.encoding import force_unicode
from django.utils.html import conditional_escape
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter(is_safe=True, needs_autoescape=True)
def join_or(value, autoescape=True):
    """
    Outputs a list as a fragment of English that has "or" in it if the list
    contains more than one item. For example, for [1, 2, 3, 4] will be output
    as "1, 2, 3 or 4".
    """
    return _join_english(u'or', value, autoescape)


@register.filter(is_safe=True, needs_autoescape=True)
def join_and(value, autoescape=True):
    return _join_english(u'and', value, autoescape)


def _join_english(word, value, autoescape=True):
    value = map(force_unicode, value)
    if autoescape:
        value = [conditional_escape(v) for v in value]

    if len(value) == 0:
        data = u''
    elif len(value) == 1:
        data = value[0]
    else:
        comma_separated = u', '.join(value[:-1])
        last = value[-1]
        data = (u' %s ' % word).join([comma_separated, last])

    return mark_safe(data)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import re
import os
import sys

root_package_dir = '.'

name = 'english-filters'
package = 'english_filters'
description = 'Django template filters for working with English text'
url = 'http://github.com/brightinteractive/english-filters/'
author = 'Bright Interactive'
author_email = 'francis@bright-interactive.com'
license = 'BSD'
install_requires = ['Django>=1.4,<1.7']
packages = find_packages(root_package_dir)


def get_version(package):
    """
    Return package version as listed in `__version__` in `init.py`.
    """
    init_py = open(os.path.join(root_package_dir, package, '__init__.py')).read()
    return re.search("^__version__ = ['\"]([^'\"]+)['\"]", init_py, re.MULTILINE).group(1)

script_args = sys.argv[1:]
display_tag_message = False

if script_args and script_args[-1] == 'publish':
    script_args[-1:] = ['sdist', 'upload']
    display_tag_message = True


setup(
    name=name,
    version=get_version(package),
    url=url,
    license=license,
    description=description,
    author=author,
    author_email=author_email,
    packages=packages,
    package_dir={'': root_package_dir},
    install_requires=install_requires,
    script_args=script_args,
    include_package_data=True
)

if display_tag_message:
    args = {'version': get_version(package)}
    print "You probably want to also tag the version now:"
    print "  git tag -a v%(version)s -m 'Version %(version)s'" % args
    print "  git push --tags"
